@@ -8,3 +8,6 @@ MAMMOTION_DOMAIN = "https://id.mammotion.com"
 MAMMOTION_API_DOMAIN = "https://domestic.mammotion.com"
 MAMMOTION_CLIENT_ID = "MADKALUBAS"
 MAMMOTION_CLIENT_SECRET = "GshzGRZJjuMUgd2sYHM7"
+
+MAMMOTION_OUATH2_CLIENT_ID = "GxebgSt8si6pKqR"
+MAMMOTION_OUATH2_CLIENT_SECRET = "JP0508SRJFa0A90ADpzLINDBxMa4Vj"
